@@ -1,5 +1,3 @@
-DATABASE_ENGINE = 'sqlite3'
-
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -14,10 +12,17 @@ INSTALLED_APPS = [
     'tests',
 ]
 
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'APP_DIRS': True,
+    },
+]
+
 ROOT_URLCONF = 'tests.urls.root'
 
 SITE_ID = 1
 
 SECRET_KEY = 'something-something'
 
-MIDDLEWARE_CLASSES = []
+USE_TZ = True
\ No newline at end of file
