@@ -1,6 +1,3 @@
-# -*- encoding: utf-8 -*-
-from __future__ import absolute_import
-
 from django.http import HttpResponse
 from django.test import RequestFactory
 from django.test.utils import override_settings
@@ -32,6 +29,7 @@ class MiddlewareTests(HostsTestCase):
             HostsRequestMiddleware)
 
     @override_settings(
+        ALLOWED_HOSTS=['other.example.com'],
         ROOT_HOSTCONF='tests.hosts.simple',
         DEFAULT_HOST='www')
     def test_request_urlconf_module(self):
@@ -42,6 +40,7 @@ class MiddlewareTests(HostsTestCase):
         self.assertEqual(request.urlconf, 'tests.urls.simple')
 
     @override_settings(
+        ALLOWED_HOSTS=['other.example.com'],
         ROOT_HOSTCONF='tests.hosts.simple',
         DEFAULT_HOST='www')
     def test_response_urlconf_module(self):
@@ -52,6 +51,7 @@ class MiddlewareTests(HostsTestCase):
         self.assertEqual(request.urlconf, 'tests.urls.simple')
 
     @override_settings(
+        ALLOWED_HOSTS=['ss.example.com'],
         ROOT_HOSTCONF='tests.hosts.simple',
         DEFAULT_HOST='with_view_kwargs')
     def test_fallback_to_defaulthost(self):
@@ -63,12 +63,25 @@ class MiddlewareTests(HostsTestCase):
         host, kwargs = middleware.get_host('non-existing')
         self.assertEqual(host.name, 'with_view_kwargs')
 
+    @override_settings(
+        ROOT_HOSTCONF='tests.hosts.simple',
+        DEFAULT_HOST='www',
+        MIDDLEWARE=[
+            'django_hosts.middleware.HostsRequestMiddleware',
+            'django_hosts.middleware.HostsResponseMiddleware',
+        ])
+    def test_request(self):
+        # This does a pass through the middleware and ensures that the
+        # middleware's __init__() assigns the get_response attribute.
+        response = self.client.get('/')
+        self.assertEqual(response.status_code, 404)
+
     @override_settings(
         ROOT_HOSTCONF='tests.hosts.simple',
         DEFAULT_HOST='www',
         ALLOWED_HOSTS=['somehost.com'],
         DEBUG=False,
-        MIDDLEWARE_CLASSES=[
+        MIDDLEWARE=[
             'django_hosts.middleware.HostsRequestMiddleware',
             'django_hosts.middleware.HostsResponseMiddleware',
         ])
@@ -77,6 +90,7 @@ class MiddlewareTests(HostsTestCase):
         self.assertEqual(response.status_code, 400)
 
     @override_settings(
+        ALLOWED_HOSTS=['spam.eggs.example.com'],
         ROOT_HOSTCONF='tests.hosts.multiple',
         DEFAULT_HOST='multiple')
     def test_multiple_subdomains(self):
@@ -87,17 +101,17 @@ class MiddlewareTests(HostsTestCase):
         self.assertEqual(request.urlconf, 'tests.urls.multiple')
 
     @override_settings(
-        MIDDLEWARE_CLASSES=['debug_toolbar.middleware.DebugToolbarMiddleware',
-                            'django_hosts.middleware.HostsRequestMiddleware'],
+        MIDDLEWARE=[
+            'debug_toolbar.middleware.DebugToolbarMiddleware',
+            'django_hosts.middleware.HostsRequestMiddleware'
+        ],
         ROOT_HOSTCONF='tests.hosts.multiple',
         DEFAULT_HOST='multiple')
     def test_debug_toolbar_new_warning(self):
-        self.assertRaises(ImproperlyConfigured, HostsRequestMiddleware)
-
-    @override_settings(
-        MIDDLEWARE_CLASSES=['debug_toolbar.middleware.DebugToolbarMiddleware',
-                            'django_hosts.middleware.HostsMiddleware'],
-        ROOT_HOSTCONF='tests.hosts.multiple',
-        DEFAULT_HOST='multiple')
-    def test_debug_toolbar_old_warning(self):
-        self.assertRaises(ImproperlyConfigured, HostsRequestMiddleware)
+        msg = (
+            'The django-hosts and django-debug-toolbar middlewares are in the '
+            'wrong order. Make sure the django-hosts middleware comes before '
+            'the django-debug-toolbar middleware in the MIDDLEWARE setting.'
+        )
+        with self.assertRaisesMessage(ImproperlyConfigured, msg):
+            HostsRequestMiddleware()
